@@ -162,7 +162,7 @@ class Builder(Update):
                         self.clVars.Get('update.cl_update_layman_make'),
                         self.clVars.Get('update.cl_update_layman_conf'),
                         prefix=self.clVars.Get('cl_builder_path'))
-        if repname != "portage":
+        if repname not in ("gentoo", "portage"):
             layman.remove(repname, rpath_orig)
             removeDir(rpath)
         return True
